.. _Resources:

Resources
=========

The Buildbot home page is http://buildbot.net/.

For configuration questions and general discussion, please use the
``buildbot-devel`` mailing list. The subscription instructions and
archives are available at
http://lists.sourceforge.net/lists/listinfo/buildbot-devel

The ``#buildbot`` channel on Freenode's IRC servers hosts development discussion, and
often folks are available to answer questions there, as well.
